"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const runner_1 = require("@garment/runner");
const Path = require("path");
const TJS = require("typescript-json-schema");
const matcher = require("matcher");
exports.default = runner_1.defineRunner(runner_1.defineOptions({ pattern: ['string?', '', '*'] }), async (ctx) => {
    const { pattern } = ctx.options;
    ctx.input(async (files) => {
        const filePaths = files.map(_ => _.absolutePath).filter(Boolean);
        const program = TJS.getProgramFromFiles(filePaths, {});
        return files.map(file => {
            const generator = TJS.buildGenerator(program, { ignoreErrors: true, required: true }, [file.absolutePath]);
            if (!generator) {
                throw new Error(`Couldn't create TJS generator for "${file.absolutePath}"`);
            }
            const symbols = generator.getMainFileSymbols(program, [
                file.absolutePath
            ]);
            const [firstSymbol] = matcher(symbols, [pattern]);
            if (!firstSymbol) {
                throw new Error(`Couldn't find an interface matching "${pattern}" in "${file.path}"`);
            }
            return ctx.file.json(Path.join(Path.dirname(file.path), 'schema.json'), generator.getSchemaForSymbol(firstSymbol));
        });
    });
});
//# sourceMappingURL=index.js.map